"""Exceptions for birch."""


class UnsupporedFormatException(Exception):
    """An exception raised when birch encounters an unsupported format."""
    pass
